pilas.escena.escena_normal

Package pilas :: Package escena :: Module escena_normal |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.escena.escena_normal

     1  # -*- encoding: utf-8 -*-
     2  # pilas engine - a video game framework.
     3  #
     4  # copyright 2010 - hugo ruscitti
     5  # license: lgplv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # website - http://www.pilas-engine.com.ar
     8  import pilas.actores
     9  from pilas.escena import Base
    10  import pilas.colores
    11  import pilas.fondos
    12
    13
    14 -class Normal(Base):
    15      """ Escena básica de pilas.
    16      Si no se define ninguna escena, cuando se ejecuta:
    17
    18      >>> pilas.iniciar()
    19      >>> pilas.ejecutar()
    20
    21      esta es la escena que se muestra en la pantalla.
    22      """
    23
    24 -    def __init__(self):
    25          Base.__init__(self)
    26
    27 -    def iniciar(self):
    28          self.fondo = pilas.fondos.Plano()
    29
    30
    31 -class Aviso(Base):
    32      """ Escena básica de pilas.
    33      Si no se define ninguna escena, cuando se ejecuta:
    34
    35      >>> pilas.iniciar()
    36      >>> pilas.ejecutar()
    37
    38      esta es la escena que se muestra en la pantalla.
    39      """
    40
    41 -    def __init__(self):
    42          Base.__init__(self)
    43
    44 -    def iniciar(self):
    45          fondo = pilas.fondos.Color(pilas.colores.grisclaro)
    46          fondo.id = "aviso1"
    47          texto = pilas.actores.Texto("Estas ejecutando la nueva version de Pilas.\n\nDebes actualizar tu codigo para que funcione\ncorrectamente.\n\nTe recomendamos que visites la documentacion.\nhttp://pilas.readthedocs.org/en/latest/\n\n\
    48          Disculpa las molestias.")
    49          texto.y = 300
    50          texto.id = "aviso2"
    51          self.pulsa_tecla_escape.conectar(self.salir)
    52
    53 -    def salir(self, evento):
    54          pilas.terminar()
    55
    56 -    def actualizar(self):
    57          if len(self.actores) > 1:
    58              for actor in self.actores:
    59                  if not('aviso' in actor.id):
    60                      actor.destruir()
    61